import pytest

def test_interoperable_with_metaclass_import():
    try:
        from trochilidae.interoperable_with_metaclass import interoperable_with_metaclass_six
    except Exception as ex:
        pytest.fail("import six failed:{0}".format(ex))

    try:
        from trochilidae.interoperable_with_metaclass import interoperable_with_metaclass_future
    except Exception as ex:
        pytest.fail("import future failed:{0}".format(ex))


import pytest

def test_interoperable_get_arg_spec():
    try:
        from trochilidae.interoperable_get_arg_spec import interoperable_get_arg_spec
    except Exception as ex:
        pytest.fail("import failed:{0}".format(ex))


from sys import version_info

__all__ = ["interoperable_reduce"]

interoperable_reduce = None

if version_info >= (3, 3):
    from functools import reduce
    interoperable_reduce = reduce
else:
    interoperable_reduce = reduce


import inspect
from sys import version_info

__all__ = ["interoperable_get_arg_spec"]

if version_info[0] >= 3:
    interoperable_get_arg_spec = inspect.getfullargspec
else:
    interoperable_get_arg_spec = inspect.getargspec


from sys import version_info

__all__ = ["interoperable_filter"]

interoperable_filter = None

if version_info >= (3, 0):
    interoperable_filter = filter
else:
    from itertools import ifilter
    interoperable_filter = ifilter


import os

from setuptools import setup, find_packages

package_name = "trochilidae"
requirements_file = "requirements.txt"
build_version_txt = "build_version.txt"

if not os.path.exists(requirements_file):
      # when we deploy this, this is where requirements will be
      requirements_file = os.path.join("{0}.egg-info".format(package_name), "requires.txt")

with open(requirements_file) as req:
    # handles custom package repos
    requirements = [requirement for requirement in req.read().splitlines() if not requirement.startswith("-")]

if not os.path.exists(build_version_txt):
    with open(os.path.join("{0}.egg-info".format(package_name), "PKG-INFO")) as pkg_info:
          pkg_info.readline()
          pkg_info.readline()
          build_number = pkg_info.readline().split(":")[1]

else:
    with open(build_version_txt) as build_file:
          release_number = build_file.readline()
          build_number_split = release_number.split(".")
          build_number = "{0}.{1}.{2}.{3}".format(*build_number_split)

setup(name=package_name,
      install_requires=requirements,
      description="version interoperability library",
      keywords="version interoperability",
      url="https://github.com/MATTHEWFRAZER/trochilidae",
      author="Matthew Frazer",
      author_email="mfrazeriguess@gmail.com",
      packages=find_packages(),
      include_package_data=False,
      zip_safe=False,
      version=build_number,
      classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            ]
      )


from future.utils import with_metaclass as with_metaclass_future
from six import with_metaclass as with_metaclass_six

__all__ = ["interoperable_with_metaclass_future", "interoperable_with_metaclass_six"]


def interoperable_with_metaclass(with_metaclass, metaclass):
    return type("{0}Wrapper".format(metaclass.__name__), (with_metaclass(metaclass),), {})


def interoperable_with_metaclass_future(metaclass):
    return interoperable_with_metaclass(with_metaclass_future, metaclass)


def interoperable_with_metaclass_six(metaclass):
    return interoperable_with_metaclass(with_metaclass_six, metaclass)



import pytest

def test_interoperable_reduce_import():
    try:
        from trochilidae.interoperable_reduce import interoperable_reduce
    except Exception as ex:
        pytest.fail("import failed:{0}".format(ex))